// serialbase.cpp: implementation of the serialbase class.
//
//////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include "serialbase.h"

#if defined(WIN32)
	#include "windows.h"
#else   // Linux
	#include <unistd.h>
	#include <termios.h>
#endif  // defined(WIN32)

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

serialbase::serialbase(const char * dev)
{
#if defined(WIN32)
	HANDLE COMW = CreateFile(dev, 0, 0, NULL, OPEN_EXISTING, 0, NULL);
	DCB dcb;
	GetCommState(COMW, &dcb);
	dcb.BaudRate=CBR_9600;
	dcb.fOutxCtsFlow = TRUE; 
	dcb.fOutxDsrFlow = FALSE;
	dcb.fRtsControl = RTS_CONTROL_HANDSHAKE;
	dcb.Parity = NOPARITY;
	dcb.ByteSize = 8;
	SetCommState(COMW, &dcb);
	CloseHandle(COMW);
#endif  // defined(WIN32)

	com = fopen(dev, "r+");
	setvbuf(com, NULL, _IONBF, 0);

#if !defined(WIN32)  // Linux

	struct termios options;
	int device = fileno(com);

	tcgetattr(device, &options); // get current options

	cfsetispeed(&options, B9600);	// change to our default inputrate
	cfsetospeed(&options, B9600);	// change to our default outputrate

	options.c_cflag |= (CLOCAL | CREAD);	// change the controlflags: dont change owner, enable receiver
	/*
	 * now change to no parity-checking
	 */
	options.c_cflag &= ~PARENB;	// disable PARENB
	options.c_cflag &= ~CSTOPB;	// disable CSTOPB
	options.c_cflag &= ~CSIZE;	// mask the character size bits
	options.c_cflag |= CS8; 	// use 8-data bits
	options.c_cflag |= CRTSCTS;// enable HardwareFlowControl

	tcsetattr(device, TCSANOW, &options);	// activate the changes immediately
	
#endif  // Linux
}

serialbase::~serialbase()
{
	fclose(com);
}
